@@ -2,7 +2,7 @@
 from __future__ import absolute_import, print_function
 
 import os
-from suanpan import path, runtime
+from suanpan import path, runtime, g
 from suanpan.arguments import Arg
 from suanpan.components import Result
 from suanpan.storage import storage
@@ -35,6 +35,7 @@ class File(StorageArg):
     def load(self, args):
         super().load(args)
         if self.value:
+            self.value = self.value.replace('{{userId}}', g.userId).replace('{{appId}}', g.appId)
             self.objectPrefix = self.value
             self.objectName = storage.storagePathJoin(self.objectPrefix, self.fileName)
             self.filePath = storage.getPathInTempStore(self.objectName)
@@ -78,6 +79,7 @@ class Folder(StorageArg):
     def load(self, args):
         super().load(args)
         if self.value:
+            self.value = self.value.replace('{{userId}}', g.userId).replace('{{appId}}', g.appId)
             self.folderName = self.value
             self.folderPath = storage.getPathInTempStore(self.folderName)
             self.value = self.folderPath
