@@ -383,7 +383,7 @@ class StreamSIOLoop(StreamBaseLoop):
 
     def __init__(self, stream):
         super().__init__(stream)
-        self.sio = socketio.Server(async_mode="gevent", cors_allowed_origins="*", json=json)
+        self.sio = socketio.Server(async_mode="gevent", cors_allowed_origins="*", json=json, max_http_buffer_size=100000000)
         self.options = self._getDefaultOptions()
         self.extraStaticFiles = {}
         self.staticFiles = {}
